@@ -8,7 +8,7 @@ void callrss(ESTRUC_ *e, FUNNR_ funnr, ...)
 {
     register E_TYPE_
         type = e_reg | e_int;               /* default return type: intreg */
-    register unsigned
+    register size_t
         args = 1;                           /* most f()s having 1 argument */
     va_list
         marker;
@@ -31,13 +31,21 @@ void callrss(ESTRUC_ *e, FUNNR_ funnr, ...)
             type = e_int | e_reg;
         break;
                                             /* 1 arg, returning string */
+        case f_strupr:
+        case f_strlwr:
         case f_ascii_str:
         case f_g_base:
         case f_g_ext:
         case f_g_path:
             type = e_str | e_reg;
         break;
+
+        case f_getenv:                      /* 1 arg, returning list */
+        case f_backtick:
+            type = e_list | e_reg;
+        break;
                                             /* 2 arguments, returning int */
+        case f_strfind:
         case f_system:
             args++;
         break;
@@ -52,6 +60,12 @@ void callrss(ESTRUC_ *e, FUNNR_ funnr, ...)
             type = e_str | e_reg;           /* returning string */
         break;
 
+                                            /* 3 args, returning string */
+        case f_substr:
+            args = 3;                       /* three arguments */
+            type = e_str | e_reg;           /* returning string */
+        break;
+
                                             /* 2 args, returning list */
         case f_stat:
         case f_fgets:                       /* list fgets(string, int) */
@@ -65,7 +79,7 @@ void callrss(ESTRUC_ *e, FUNNR_ funnr, ...)
         case f_exec:
         case f_fprintf:
         case f_printf:
-            args = va_arg(marker, unsigned);
+            args = va_arg(marker, size_t);
         break;
 
         default:
@@ -84,6 +98,7 @@ void callrss(ESTRUC_ *e, FUNNR_ funnr, ...)
             case f_echo:
             case f_exists:
             case f_sizeoflist:
+            case f_strlen:
         */
     break;
     }
@@ -91,3 +106,6 @@ void callrss(ESTRUC_ *e, FUNNR_ funnr, ...)
         gencode (e, op_asp, args);          /* add stack pointer */
     set_type(e, type);                      /* type of resulting expression */
 }
+
+
+
