@@ -10,7 +10,7 @@ void listCompare(LISTVAR_ *lhs, LISTVAR_ const *rhs)
     if (l_size != size(rhs))
     {
         listDestructor(lhs);
-        *lhs = intConstructor_i(l_size - size(rhs));
+        *lhs = *intConstructor_i((int)(l_size - size(rhs)));
         return;
     }
 
@@ -24,5 +24,5 @@ void listCompare(LISTVAR_ *lhs, LISTVAR_ const *rhs)
                                 /* the non-16 bit return value may have its */
                                 /* lower 16 bits set to zero (as happened   */
                                 /* on the powerpc                           */
-    *lhs = intConstructor_i(ret < 0 ? -1 : ret > 0 ? 1 : 0);
+    *lhs = *intConstructor_i(ret < 0 ? -1 : ret > 0 ? 1 : 0);
 }
