@@ -1,24 +1,20 @@
 #ifndef _INCLUDED_ICRSSDEF_H_
 #define _INCLUDED_ICRSSDEF_H_
 
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <signal.h>
-#include <ctype.h>
-#include <stdarg.h>
-#include <malloc.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#ifdef MSDOS
-#   include <dos.h>
-#   include <io.h>
-#   include <process.h>
-#else
-#   include <unistd.h>
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
 #endif
 
+#include <ctype.h>
+#include <signal.h>
+#include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
+
 #include "icrss.h"
 
 #endif
